@@ -35,7 +35,7 @@ to a BIND readable text form.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.14'
+__version__ = '0.15'
 
 
 import bz2
@@ -45,6 +45,7 @@ import os
 import StringIO
 import shutil
 import tarfile
+import punycode_lib
 
 from roster_core import audit_log
 from roster_core import config
@@ -229,9 +230,10 @@ class BindTreeExport(object):
             if( audit_rows ):
               audit_rows = self.db_instance.ListRow(
                   'audit_log', self.db_instance.GetEmptyRowDict('audit_log'),
-                  date_column='audit_log_timestamp',
-                  date_range=(audit_rows[-1]['audit_log_timestamp'],
-                              datetime.datetime.now()))
+                  column='audit_log_timestamp',
+                  range_values=(audit_rows[-1]['audit_log_timestamp'],
+                              datetime.datetime.now()),
+                  is_date=True)
               for row in audit_rows:
                 if( row['action'] != u'ExportAllBindTrees' ):
                   break
@@ -309,6 +311,7 @@ class BindTreeExport(object):
                 cooked_data[dns_server_set]['views'][view]['zones'][zone][
                     'zone_origin'],
                 record_argument_definitions, zone, view)
+
             self.AddToTarFile(tar_file, zone_file, zone_file_string)
         named_conf_file = '%s/named.conf' % named_directory.rstrip('/')
         named_conf_file_string = self.MakeNamedConf(data, cooked_data,
@@ -337,6 +340,8 @@ class BindTreeExport(object):
 
         'w')
     try:
+      for audit_index, audit_entry in enumerate(audit_log_replay_dump):
+        audit_log_replay_dump[audit_index] = audit_entry.encode('utf-8')
       audit_log_replay_dump_file.writelines(audit_log_replay_dump)
     finally:
       audit_log_replay_dump_file.close()
@@ -344,6 +349,8 @@ class BindTreeExport(object):
     full_dump_file = bz2.BZ2File('%s/full_database_dump-%s.bz2' % 
                                  (self.backup_dir, log_id), 'w')
     try:
+      for full_dump_index, full_dump_entry in enumerate(full_database_dump):
+        full_database_dump[full_dump_index] = full_dump_entry.encode('utf-8')
       full_dump_file.writelines(full_database_dump)
     finally:
       full_dump_file.close()
@@ -758,11 +765,24 @@ class BindTreeExport(object):
                       cooked_data[dns_server_set_name]['views'][view_name][
                           'zones'][zone_name]['records'] = []
 
+                  for record in sorted_records[(
+                      zone_name, view_dependency_name)].values():
+                    try:
+                      record['target'] = punycode_lib.Uni2Puny(record['target'])
+                    except (KeyError):
+                      pass
+                    try:
+                      record['assignment_host'] = punycode_lib.Uni2Puny(
+                          record['assignment_host'])
+                    except (KeyError):
+                      pass
                   cooked_data[dns_server_set_name]['views'][view_name][
                       'zones'][zone_name]['records'].extend(sorted_records[(
                           zone_name, view_dependency_name)].values())
+
                   cooked_data[dns_server_set_name]['views'][view_name][
-                      'zones'][zone_name]['zone_origin'] = zone['zone_origin']
+                      'zones'][zone_name]['zone_origin'] = punycode_lib.Uni2Puny(
+                          zone['zone_origin'])
 
                   cooked_data[dns_server_set_name]['views'][view_name][
                       'zones'][zone_name]['zone_options'] = zone['zone_options']
